==> jc-1.4.0.tar.gz: soot/grimp/internal/GInvokeStmt.h <==
// public class soot.grimp.internal.GInvokeStmt

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 79fe89e6db90880b soot_grimp_internal_GInvokeStmt
// @dep_class b3c0d2cd30f6acdd soot_jimple_internal_AbstractStmt
// @dep_class 9bd832fad7d8404f soot_jimple_internal_JInvokeStmt
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_jimple_internal_JInvokeStmt

#include "soot/jimple/internal/JInvokeStmt.h"

#ifndef _JC_soot_grimp_internal_GInvokeStmt_H_
#define _JC_soot_grimp_internal_GInvokeStmt_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GInvokeStmt$sub_refs	_jc_soot_grimp_internal_GInvokeStmt$sub_refs;
typedef struct _jc_soot_grimp_internal_GInvokeStmt$sub_nonrefs	_jc_soot_grimp_internal_GInvokeStmt$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GInvokeStmt$refs	_jc_soot_grimp_internal_GInvokeStmt$refs;
typedef struct _jc_soot_grimp_internal_GInvokeStmt$nonrefs	_jc_soot_grimp_internal_GInvokeStmt$nonrefs;
typedef struct _jc_soot_grimp_internal_GInvokeStmt$object	_jc_soot_grimp_internal_GInvokeStmt$object;

typedef const struct _jc_soot_grimp_internal_GInvokeStmt$vmethods	_jc_soot_grimp_internal_GInvokeStmt$vmethods;
typedef const struct _jc_soot_grimp_internal_GInvokeStmt$vtable	_jc_soot_grimp_internal_GInvokeStmt$vtable;
typedef const struct _jc_soot_grimp_internal_GInvokeStmt$vtype	_jc_soot_grimp_internal_GInvokeStmt$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GInvokeStmt$method$_init$b01f06481db4410b(_jc_env *, struct _jc_soot_grimp_internal_GInvokeStmt$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GInvokeStmt$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GInvokeStmt$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GInvokeStmt$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_grimp_internal_GInvokeStmt$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GInvokeStmt$object *);
};

// Vtable
struct _jc_soot_grimp_internal_GInvokeStmt$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_jimple_internal_AbstractStmt$vmethods	soot_jimple_internal_AbstractStmt;
	_jc_soot_jimple_internal_JInvokeStmt$vmethods	soot_jimple_internal_JInvokeStmt;
	_jc_soot_grimp_internal_GInvokeStmt$vmethods	soot_grimp_internal_GInvokeStmt;
};

// Vtype
struct _jc_soot_grimp_internal_GInvokeStmt$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GInvokeStmt$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GInvokeStmt$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GInvokeStmt$refs {
    _jc_soot_grimp_internal_GInvokeStmt$sub_refs	soot_grimp_internal_GInvokeStmt;
    _jc_soot_jimple_internal_JInvokeStmt$sub_refs	soot_jimple_internal_JInvokeStmt;
    _jc_soot_jimple_internal_AbstractStmt$sub_refs	soot_jimple_internal_AbstractStmt;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GInvokeStmt$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GInvokeStmt$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_jimple_internal_AbstractStmt$sub_nonrefs	soot_jimple_internal_AbstractStmt;
    _jc_soot_jimple_internal_JInvokeStmt$sub_nonrefs	soot_jimple_internal_JInvokeStmt;
    _jc_soot_grimp_internal_GInvokeStmt$sub_nonrefs	soot_grimp_internal_GInvokeStmt;
};

// Object instance structure
struct _jc_soot_grimp_internal_GInvokeStmt$object {
	_jc_soot_grimp_internal_GInvokeStmt$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GInvokeStmt$vtype	*vtype;
	_jc_soot_grimp_internal_GInvokeStmt$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GInvokeStmt$vtype _jc_soot_grimp_internal_GInvokeStmt$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GInvokeStmt, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GInvokeStmt$class_object;

#endif	/* _JC_soot_grimp_internal_GInvokeStmt_H_ */

==> jc-1.4.6.tar.gz: soot/grimp/internal/GInvokeStmt.h <==
// public class soot.grimp.internal.GInvokeStmt

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 79fe89e6db90880b soot_grimp_internal_GInvokeStmt
// @dep_class b3c0d2cd30f6acdd soot_jimple_internal_AbstractStmt
// @dep_class 9bd832fad7d8404f soot_jimple_internal_JInvokeStmt
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_jimple_internal_JInvokeStmt

#include "soot/jimple/internal/JInvokeStmt.h"

#ifndef _JC_soot_grimp_internal_GInvokeStmt_H_
#define _JC_soot_grimp_internal_GInvokeStmt_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GInvokeStmt$sub_refs	_jc_soot_grimp_internal_GInvokeStmt$sub_refs;
typedef struct _jc_soot_grimp_internal_GInvokeStmt$sub_nonrefs	_jc_soot_grimp_internal_GInvokeStmt$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GInvokeStmt$refs	_jc_soot_grimp_internal_GInvokeStmt$refs;
typedef struct _jc_soot_grimp_internal_GInvokeStmt$nonrefs	_jc_soot_grimp_internal_GInvokeStmt$nonrefs;
typedef struct _jc_soot_grimp_internal_GInvokeStmt$object	_jc_soot_grimp_internal_GInvokeStmt$object;

typedef const struct _jc_soot_grimp_internal_GInvokeStmt$vmethods	_jc_soot_grimp_internal_GInvokeStmt$vmethods;
typedef const struct _jc_soot_grimp_internal_GInvokeStmt$vtable	_jc_soot_grimp_internal_GInvokeStmt$vtable;
typedef const struct _jc_soot_grimp_internal_GInvokeStmt$vtype	_jc_soot_grimp_internal_GInvokeStmt$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GInvokeStmt$method$_init$b01f06481db4410b(_jc_env *, struct _jc_soot_grimp_internal_GInvokeStmt$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GInvokeStmt$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GInvokeStmt$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GInvokeStmt$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_grimp_internal_GInvokeStmt$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GInvokeStmt$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_grimp_internal_GInvokeStmt$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_jimple_internal_AbstractStmt$vmethods	soot_jimple_internal_AbstractStmt;
	_jc_soot_jimple_internal_JInvokeStmt$vmethods	soot_jimple_internal_JInvokeStmt;
	_jc_soot_grimp_internal_GInvokeStmt$vmethods	soot_grimp_internal_GInvokeStmt;
};

// Vtype
struct _jc_soot_grimp_internal_GInvokeStmt$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GInvokeStmt$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GInvokeStmt$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GInvokeStmt$refs {
    _jc_soot_grimp_internal_GInvokeStmt$sub_refs	soot_grimp_internal_GInvokeStmt;
    _jc_soot_jimple_internal_JInvokeStmt$sub_refs	soot_jimple_internal_JInvokeStmt;
    _jc_soot_jimple_internal_AbstractStmt$sub_refs	soot_jimple_internal_AbstractStmt;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GInvokeStmt$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GInvokeStmt$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_jimple_internal_AbstractStmt$sub_nonrefs	soot_jimple_internal_AbstractStmt;
    _jc_soot_jimple_internal_JInvokeStmt$sub_nonrefs	soot_jimple_internal_JInvokeStmt;
    _jc_soot_grimp_internal_GInvokeStmt$sub_nonrefs	soot_grimp_internal_GInvokeStmt;
};

// Object instance structure
struct _jc_soot_grimp_internal_GInvokeStmt$object {
	_jc_soot_grimp_internal_GInvokeStmt$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GInvokeStmt$vtype	*vtype;
	_jc_soot_grimp_internal_GInvokeStmt$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GInvokeStmt$vtype _jc_soot_grimp_internal_GInvokeStmt$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GInvokeStmt, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GInvokeStmt$class_object;

#endif	/* _JC_soot_grimp_internal_GInvokeStmt_H_ */
